@@ -8,14 +8,14 @@
 
 main(int argc,char *argv[])
 {
-    MP_INT *e,*n,*c;
-    char pubfile[128]; int i;
-    unsigned char key[32];
-    unsigned char cipher[MAXC];
+    char pubfile[128]; unsigned int i,k;
+    unsigned char key[48], cipher[MAXC];
     FILE *public;
+    MP_INT *e,*n,*c;
     init(e); init(n); init(c);
+
     if (argc < 2) {
-        fprintf(stderr, "usage: encrypt pubfile\n");
+        fprintf(stderr, "usage: encrypt pubfile [randomdata...] \n");
         exit(1);
     }
     
@@ -28,16 +28,21 @@ main(int argc,char *argv[])
     }
 
     initrandom();
+	for (i=2; i<argc;i++)
+		if (argv[i] && (k=strlen(argv[i])))  {
+			seedrandom((unsigned char *)argv[i],k);
+			zap((unsigned char *)argv[i],k);
+		}
     fprintf(stderr, "please enter a random string -- end with <CR>\n");
     (void)getstring(0);
-    for (i=0;i<32;i++)
+    for (i=0;i<48;i++)
         key[i] = randombyte();
 
     read_number(public,n);
     read_number(public,e);
     encrypt_session_key(c,key,n,e);
     write_number(stdout,c);
-    desfile(stdin,stdout,&key[0], &key[24], EN0);
-	zap(key,32);
+    desfile(stdin,stdout,&key[0], &key[40], EN0);
+	zap(key,48); closerandom();
 }
 
